==> xlniuxdata-vipgame-1.0.57-20160427.033318-5-sources.jar: com/xunlei/niux/data/vipgame/vo/business/IntoSystem.java <==
package com.xunlei.niux.data.vipgame.vo.business;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;

/**
 * 分成
 * @author hezhong
 */
@Table(tableName = "intosystem", pkFieldName = "seqid", pkFieldAssign = false)
public class IntoSystem {

    private Integer seqid;

    private String gameid;

    private Integer systype;

    private Integer intoratio;
    
    private Integer qudao;

	private Boolean noregulartype;

    private Integer beginmoney;

    private Integer endmoney;

    private String inputby;

    private String inputtime;

    private String editby;

    private String edittime;

    @Exclude
    private String desc;

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public Integer getIntoratio() {
        return intoratio;
    }

    public void setIntoratio(Integer intoratio) {
        this.intoratio = intoratio;
    }

    public Boolean getNoregulartype() {
        return noregulartype;
    }

    public void setNoregulartype(Boolean noregulartype) {
        this.noregulartype = noregulartype;
    }
    public Integer getQudao() {
		return qudao;
	}

	public void setQudao(Integer qudao) {
		this.qudao = qudao;
	}
    public Integer getSeqid() {
        return seqid;
    }

    public void setSeqid(Integer seqid) {
        this.seqid = seqid;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }

    public Integer getSystype() {
        return systype;
    }

    public void setSystype(Integer systype) {
        this.systype = systype;
    }



    public Integer getBeginmoney() {
        return beginmoney;
    }

    public void setBeginmoney(Integer beginmoney) {
        this.beginmoney = beginmoney;
    }

    public Integer getEndmoney() {
        return endmoney;
    }

    public void setEndmoney(Integer endmoney) {
        this.endmoney = endmoney;
    }

    public String getInputby() {
        return inputby;
    }

    public void setInputby(String inputby) {
        this.inputby = inputby;
    }

    public String getInputtime() {
        return inputtime;
    }

    public void setInputtime(String inputtime) {
        this.inputtime = inputtime;
    }

    public String getEditby() {
        return editby;
    }

    public void setEditby(String editby) {
        this.editby = editby;
    }

    public String getEdittime() {
        return edittime;
    }

    public void setEdittime(String edittime) {
        this.edittime = edittime;
    }
}

==> xlniuxdata-vipgame-1.0.65-20170818.061400-102-sources.jar: com/xunlei/niux/data/vipgame/vo/business/IntoSystem.java <==
package com.xunlei.niux.data.vipgame.vo.business;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;

/**
 * 分成
 * @author hezhong
 */
@Table(tableName = "intosystem", pkFieldName = "seqid", pkFieldAssign = false)
public class IntoSystem {

    private Integer seqid;

    private String gameid;

    /*
     * 0：固定分成
     * 1：不固定分成
     * 2：固定分成（去除渠道成本）
     * 3：不固定分成（去除渠道成本）
     * 4：固定分成（增加现金券分成）
     * 5：不固定分成（增加现金券分成）
     */
    private Integer systype;

    private Integer intoratio;
    
    private Integer qudao;
    
    private Integer niuxcashratio;

	private Boolean noregulartype;

    private Integer beginmoney;

    private Integer endmoney;

    private String inputby;

    private String inputtime;

    private String editby;

    private String edittime;

    @Exclude
    private String desc;

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public Integer getIntoratio() {
        return intoratio;
    }

    public void setIntoratio(Integer intoratio) {
        this.intoratio = intoratio;
    }

    public Boolean getNoregulartype() {
        return noregulartype;
    }

    public void setNoregulartype(Boolean noregulartype) {
        this.noregulartype = noregulartype;
    }
    public Integer getQudao() {
		return qudao;
	}

	public void setQudao(Integer qudao) {
		this.qudao = qudao;
	}
    public Integer getSeqid() {
        return seqid;
    }

    public void setSeqid(Integer seqid) {
        this.seqid = seqid;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }

    public Integer getSystype() {
        return systype;
    }

    public void setSystype(Integer systype) {
        this.systype = systype;
    }



    public Integer getBeginmoney() {
        return beginmoney;
    }

    public void setBeginmoney(Integer beginmoney) {
        this.beginmoney = beginmoney;
    }

    public Integer getEndmoney() {
        return endmoney;
    }

    public void setEndmoney(Integer endmoney) {
        this.endmoney = endmoney;
    }

    public String getInputby() {
        return inputby;
    }

    public void setInputby(String inputby) {
        this.inputby = inputby;
    }

    public String getInputtime() {
        return inputtime;
    }

    public void setInputtime(String inputtime) {
        this.inputtime = inputtime;
    }

    public String getEditby() {
        return editby;
    }

    public void setEditby(String editby) {
        this.editby = editby;
    }

    public String getEdittime() {
        return edittime;
    }

    public void setEdittime(String edittime) {
        this.edittime = edittime;
    }

	public Integer getNiuxcashratio() {
		return niuxcashratio;
	}

	public void setNiuxcashratio(Integer niuxcashratio) {
		this.niuxcashratio = niuxcashratio;
	}
}
